==> dojo-1.9.4.tgz: package/cldr/nls/ru/hebrew.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"вс",
		"пн",
		"вт",
		"ср",
		"чт",
		"пт",
		"сб"
	],
	"field-weekday": "День недели",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-MMMEd": "ccc, d MMM",
	"days-format-short": [
		"вс",
		"пн",
		"вт",
		"ср",
		"чт",
		"пт",
		"сб"
	],
	"dateFormat-long": "d MMMM y 'г'. G",
	"months-format-wide": [
		"Тишрей",
		"Хешван",
		"Кислев",
		"Тевет",
		"Шеват",
		"Адар I",
		"Адар",
		"Нисан",
		"Ияр",
		"Сиван",
		"Таммуз",
		"Ав",
		"Элул"
	],
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateTimeFormat-medium": "{1}, {0}",
	"dayPeriods-format-wide-pm": "после полудня",
	"dateFormat-full": "EEEE, d MMMM y 'г'. G",
	"dateFormatItem-yyyyMEd": "E, dd.MM.y G",
	"dateFormatItem-Md": "dd.MM",
	"dayPeriods-format-abbr-am": "до полудня",
	"field-era": "Эра",
	"months-standAlone-wide": [
		"Тишрей",
		"Хешван",
		"Кислев",
		"Тевет",
		"Шеват",
		"Адар I",
		"Адар",
		"Нисан",
		"Ияр",
		"Сиван",
		"Таммуз",
		"Ав",
		"Элул"
	],
	"timeFormat-short": "H:mm",
	"quarters-format-wide": [
		"1-й квартал",
		"2-й квартал",
		"3-й квартал",
		"4-й квартал"
	],
	"timeFormat-long": "H:mm:ss z",
	"field-year": "Год",
	"field-hour": "Час",
	"months-format-abbr-leap": "Адар II",
	"months-format-abbr": [
		"Тишрей",
		"Хешван",
		"Кислев",
		"Тевет",
		"Шеват",
		"Адар I",
		"Адар",
		"Нисан",
		"Ияр",
		"Сиван",
		"Таммуз",
		"Ав",
		"Элул"
	],
	"timeFormat-full": "H:mm:ss zzzz",
	"field-day-relative+0": "Сегодня",
	"field-day-relative+1": "Завтра",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "Послезавтра",
	"dateFormatItem-H": "H",
	"months-standAlone-abbr": [
		"Тишрей",
		"Хешван",
		"Кислев",
		"Тевет",
		"Шеват",
		"Адар I",
		"Адар",
		"Нисан",
		"Ияр",
		"Сиван",
		"Таммуз",
		"Ав",
		"Элул"
	],
	"quarters-format-abbr": [
		"1-й кв.",
		"2-й кв.",
		"3-й кв.",
		"4-й кв."
	],
	"quarters-standAlone-wide": [
		"1-й квартал",
		"2-й квартал",
		"3-й квартал",
		"4-й квартал"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"days-standAlone-wide": [
		"Воскресенье",
		"Понедельник",
		"Вторник",
		"Среда",
		"Четверг",
		"Пятница",
		"Суббота"
	],
	"dateFormatItem-yyyyMMM": "LLL y G",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"months-standAlone-wide-leap": "Адар II",
	"timeFormat-medium": "H:mm:ss",
	"dateFormatItem-Hm": "H:mm",
	"quarters-standAlone-abbr": [
		"1-й кв.",
		"2-й кв.",
		"3-й кв.",
		"4-й кв."
	],
	"field-minute": "Минута",
	"field-dayperiod": "ДП/ПП",
	"days-standAlone-abbr": [
		"Вс",
		"Пн",
		"Вт",
		"Ср",
		"Чт",
		"Пт",
		"Сб"
	],
	"field-day-relative+-1": "Вчера",
	"dateTimeFormat-long": "{1}, {0}",
	"dayPeriods-format-narrow-am": "дп",
	"field-day-relative+-2": "Позавчера",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, dd.MM",
	"dateTimeFormat-full": "{1}, {0}",
	"field-day": "День",
	"days-format-wide": [
		"воскресенье",
		"понедельник",
		"вторник",
		"среда",
		"четверг",
		"пятница",
		"суббота"
	],
	"field-zone": "Часовой пояс",
	"months-standAlone-abbr-leap": "Адар II",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "В прошлом году",
	"field-month-relative+-1": "В прошлом месяце",
	"dayPeriods-format-abbr-pm": "после полудня",
	"days-format-abbr": [
		"вс",
		"пн",
		"вт",
		"ср",
		"чт",
		"пт",
		"сб"
	],
	"days-format-narrow": [
		"вс",
		"пн",
		"вт",
		"ср",
		"чт",
		"пт",
		"сб"
	],
	"dateFormatItem-yyyyMd": "dd.MM.y G",
	"field-month": "Месяц",
	"days-standAlone-narrow": [
		"В",
		"П",
		"В",
		"С",
		"Ч",
		"П",
		"С"
	],
	"dayPeriods-format-wide-am": "до полудня",
	"dateFormat-short": "dd.MM.y G",
	"field-second": "Секунда",
	"field-month-relative+0": "В этом месяце",
	"field-month-relative+1": "В следующем месяце",
	"dateFormatItem-Ed": "E, d",
	"field-week": "Неделя",
	"dateFormat-medium": "dd.MM.y G",
	"field-year-relative+0": "В этом году",
	"field-week-relative+-1": "На прошлой неделе",
	"dateFormatItem-yyyyM": "MM.y G",
	"field-year-relative+1": "В следующем году",
	"dayPeriods-format-narrow-pm": "пп",
	"dateFormatItem-yyyyQQQQ": "QQQQ y 'г'. G",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-Hms": "H:mm:ss",
	"months-format-wide-leap": "Адар II",
	"dateFormatItem-GyMMM": "LLL y G",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "На этой неделе",
	"field-week-relative+1": "На следующей неделе"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/ru/hebrew.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"вс",
		"пн",
		"вт",
		"ср",
		"чт",
		"пт",
		"сб"
	],
	"field-second-relative+0": "сейчас",
	"field-weekday": "День недели",
	"field-wed-relative+0": "в эту среду",
	"field-wed-relative+1": "в следующую среду",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-MMMEd": "ccc, d MMM",
	"field-tue-relative+-1": "в прошлый вторник",
	"days-format-short": [
		"вс",
		"пн",
		"вт",
		"ср",
		"чт",
		"пт",
		"сб"
	],
	"dateFormat-long": "d MMMM y 'г'. G",
	"field-fri-relative+-1": "в прошлую пятницу",
	"field-wed-relative+-1": "в прошлую среду",
	"months-format-wide": [
		"Тишрей",
		"Хешван",
		"Кислев",
		"Тевет",
		"Шеват",
		"Адар I",
		"Адар",
		"Нисан",
		"Ияр",
		"Сиван",
		"Таммуз",
		"Ав",
		"Элул"
	],
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateTimeFormat-medium": "{1}, {0}",
	"dateFormat-full": "EEEE, d MMMM y 'г'. G",
	"dateFormatItem-yyyyMEd": "E, dd.MM.y G",
	"field-thu-relative+-1": "в прошлый четверг",
	"dateFormatItem-Md": "dd.MM",
	"field-era": "Эра",
	"months-standAlone-wide": [
		"Тишрей",
		"Хешван",
		"Кислев",
		"Тевет",
		"Шеват",
		"Адар I",
		"Адар",
		"Нисан",
		"Ияр",
		"Сиван",
		"Таммуз",
		"Ав",
		"Элул"
	],
	"timeFormat-short": "H:mm",
	"quarters-format-wide": [
		"1-й квартал",
		"2-й квартал",
		"3-й квартал",
		"4-й квартал"
	],
	"timeFormat-long": "H:mm:ss z",
	"field-year": "Год",
	"field-hour": "Час",
	"months-format-abbr-leap": "Адар II",
	"months-format-abbr": [
		"Тишрей",
		"Хешван",
		"Кислев",
		"Тевет",
		"Шеват",
		"Адар I",
		"Адар",
		"Нисан",
		"Ияр",
		"Сиван",
		"Таммуз",
		"Ав",
		"Элул"
	],
	"field-sat-relative+0": "в эту субботу",
	"field-sat-relative+1": "в следующую субботу",
	"timeFormat-full": "H:mm:ss zzzz",
	"field-day-relative+0": "сегодня",
	"field-thu-relative+0": "в этот четверг",
	"field-day-relative+1": "завтра",
	"field-thu-relative+1": "в следующий четверг",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "послезавтра",
	"dateFormatItem-H": "H",
	"months-standAlone-abbr": [
		"Тишрей",
		"Хешван",
		"Кислев",
		"Тевет",
		"Шеват",
		"Адар I",
		"Адар",
		"Нисан",
		"Ияр",
		"Сиван",
		"Таммуз",
		"Ав",
		"Элул"
	],
	"quarters-format-abbr": [
		"1-й кв.",
		"2-й кв.",
		"3-й кв.",
		"4-й кв."
	],
	"quarters-standAlone-wide": [
		"1-й квартал",
		"2-й квартал",
		"3-й квартал",
		"4-й квартал"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"days-standAlone-wide": [
		"Воскресенье",
		"Понедельник",
		"Вторник",
		"Среда",
		"Четверг",
		"Пятница",
		"Суббота"
	],
	"dateFormatItem-yyyyMMM": "LLL y G",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"months-standAlone-wide-leap": "Адар II",
	"timeFormat-medium": "H:mm:ss",
	"field-sun-relative+0": "в это воскресенье",
	"dateFormatItem-Hm": "H:mm",
	"field-sun-relative+1": "в следующее воскресенье",
	"quarters-standAlone-abbr": [
		"1-й кв.",
		"2-й кв.",
		"3-й кв.",
		"4-й кв."
	],
	"field-minute": "Минута",
	"field-dayperiod": "ДП/ПП",
	"days-standAlone-abbr": [
		"Вс",
		"Пн",
		"Вт",
		"Ср",
		"Чт",
		"Пт",
		"Сб"
	],
	"field-day-relative+-1": "вчера",
	"dateTimeFormat-long": "{1}, {0}",
	"dayPeriods-format-narrow-am": "AM",
	"field-day-relative+-2": "позавчера",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, dd.MM",
	"dateTimeFormat-full": "{1}, {0}",
	"field-fri-relative+0": "в эту пятницу",
	"field-fri-relative+1": "в следующую пятницу",
	"field-day": "День",
	"days-format-wide": [
		"воскресенье",
		"понедельник",
		"вторник",
		"среда",
		"четверг",
		"пятница",
		"суббота"
	],
	"field-zone": "Часовой пояс",
	"months-standAlone-abbr-leap": "Адар II",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "в прошлом году",
	"field-month-relative+-1": "в прошлом месяце",
	"days-format-abbr": [
		"вс",
		"пн",
		"вт",
		"ср",
		"чт",
		"пт",
		"сб"
	],
	"days-format-narrow": [
		"вс",
		"пн",
		"вт",
		"ср",
		"чт",
		"пт",
		"сб"
	],
	"dateFormatItem-yyyyMd": "dd.MM.y G",
	"field-month": "Месяц",
	"days-standAlone-narrow": [
		"В",
		"П",
		"В",
		"С",
		"Ч",
		"П",
		"С"
	],
	"field-tue-relative+0": "в этот вторник",
	"field-tue-relative+1": "в следующий вторник",
	"field-mon-relative+0": "в этот понедельник",
	"field-mon-relative+1": "в следующий понедельник",
	"dateFormat-short": "dd.MM.y G",
	"field-second": "Секунда",
	"field-sat-relative+-1": "в прошлую субботу",
	"field-sun-relative+-1": "в прошлое воскресенье",
	"field-month-relative+0": "в этом месяце",
	"field-month-relative+1": "в следующем месяце",
	"dateFormatItem-Ed": "E, d",
	"field-week": "Неделя",
	"dateFormat-medium": "d MMM y 'г'. G",
	"field-year-relative+0": "в этому году",
	"field-week-relative+-1": "на прошлой неделе",
	"dateFormatItem-yyyyM": "MM.y G",
	"field-year-relative+1": "в следующем году",
	"dayPeriods-format-narrow-pm": "PM",
	"dateFormatItem-yyyyQQQQ": "QQQQ y 'г'. G",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-Hms": "H:mm:ss",
	"months-format-wide-leap": "Адар II",
	"dateFormatItem-GyMMM": "LLL y G",
	"field-mon-relative+-1": "в прошлый понедельник",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "на этой неделе",
	"field-week-relative+1": "на следующей неделе"
}
//end v1.x content
);
